@@ -1,6 +1,6 @@
 /* godaemon.c
  *
- * Copyright 2003, Michael Robinton <michael@bizsystems.com>
+ * Copyright 2003 - 2009, Michael Robinton <michael@bizsystems.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,7 +27,9 @@
 static __inline void godaemon(void) {
   extern char devnull[];
   pid_t pid;
-
+/* suppress annoying compiler warnings	*/
+  int discard;
+  
   if ((pid = fork()) != 0)
     exit(0);			/* parent exits		*/
   
@@ -38,14 +40,14 @@ static __inline void godaemon(void) {
   if ((pid = fork()) != 0)	/* double fork		*/
     exit(0);			/* 1st child exits	*/
 
-  chdir("/");
+  discard = chdir("/");
   /* redirect stdin/stdout/stderr to /dev/null */
   close(0);
   close(1);
   close(2);
   open(devnull, O_RDWR);
-  dup(0);
-  dup(0);
+  discard = dup(0);
+  discard = dup(0);
   return;
 }
 
