@@ -1,3 +1,5 @@
 /* misc_func.h -- included in main.c */
 void LogPrint(char *output);
 void CleanExit(int sig);
+int realMain(int argc, char **argv);
+void set_signals (void);
